package uring

  1. Overview
  2. Docs

Module Uring.Poll_maskSource

include FLAGS
Sourcetype t = private int

A set of flags.

Sourceval empty : t
Sourceval of_int : int -> t

of_int i is the flags whose bits are those set in i.

Sourceval to_int : t -> int

to_int t is the integer with the bits of the flags t set.

Sourceval (+) : t -> t -> t

a + b is the union of the sets.

Sourceval mem : t -> t -> bool

mem x flags is true iff x is a subset of flags.

Sourceval (=) : t -> t -> bool

a = b is true iff a and b are the same set of flags.

Sourceval pollin : t
Sourceval pollout : t
Sourceval pollerr : t
Sourceval pollhup : t