You can search for identifiers within the package.
in-package search v0.2.0
uring
Uring.Poll_mask
include FLAGS
type t = private int
A set of flags.
val empty : t
val of_int : int -> t
of_int i is the flags whose bits are those set in i.
of_int i
i
val to_int : t -> int
to_int t is the integer with the bits of the flags t set.
to_int t
t
val (+) : t -> t -> t
a + b is the union of the sets.
a + b
val mem : t -> t -> bool
mem x flags is true iff x is a subset of flags.
mem x flags
true
x
flags
val (=) : t -> t -> bool
a = b is true iff a and b are the same set of flags.
a = b
a
b
val pollin : t
val pollout : t
val pollerr : t
val pollhup : t